@@ -35,7 +35,8 @@ class GMXCluster():
             * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
     """
 
-    def __init__(self, input_structure_path, input_traj_path, output_pdb_path, input_index_path=None, properties=None, **kwargs):
+    def __init__(self, input_structure_path, input_traj_path, 
+                 output_pdb_path, input_index_path=None, properties=None, **kwargs) -> None:
         properties = properties or {}
 
         # Input/Output files
@@ -89,7 +90,7 @@ class GMXCluster():
         self.cutoff = get_cutoff(self.properties, out_log, self.__class__.__name__)
 
     @launchlogger
-    def launch(self):
+    def launch(self) -> int:
         """Launches the execution of the GROMACS rms module."""
 
         # Get local loggers from launchlogger decorator
