@@ -37,7 +37,8 @@ class GMXImage():
             * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
     """
 
-    def __init__(self, input_traj_path, input_top_path, output_traj_path, input_index_path=None, properties=None, **kwargs):
+    def __init__(self, input_traj_path, input_top_path, 
+                 output_traj_path, input_index_path=None, properties=None, **kwargs) -> None:
         properties = properties or {}
 
         # Input/Output files
@@ -89,7 +90,7 @@ class GMXImage():
         self.fit = get_fit(self.properties, out_log, self.__class__.__name__)
 
     @launchlogger
-    def launch(self):
+    def launch(self) -> int:
         """Launches the execution of the GROMACS rgyr module."""
 
         # Get local loggers from launchlogger decorator
