@@ -33,7 +33,8 @@ class GMXTrjConvTrj():
             * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
     """
 
-    def __init__(self, input_traj_path, output_traj_path, input_index_path=None, properties=None, **kwargs):
+    def __init__(self, input_traj_path, 
+                 output_traj_path, input_index_path=None, properties=None, **kwargs) -> None:
         properties = properties or {}
 
         # Input/Output files
@@ -79,7 +80,7 @@ class GMXTrjConvTrj():
         self.dt = get_dt(self.properties, out_log, self.__class__.__name__)
 
     @launchlogger
-    def launch(self):
+    def launch(self) -> int:
         """Launches the execution of the GROMACS rgyr module."""
         
         # Get local loggers from launchlogger decorator
